@@ -16,34 +16,32 @@ with no fancy additions whatsoever.
 """
 
 # get PyMVPA running
-from mvpa.suite import *
+from mvpa2.suite import *
 
 # load PyMVPA example dataset
-attr = SampleAttributes(os.path.join(pymvpa_dataroot, 'attributes.txt'))
-dataset = NiftiDataset(samples=os.path.join(pymvpa_dataroot, 'bold.nii.gz'),
-                       labels=attr.labels,
-                       chunks=attr.chunks,
+attr = SampleAttributes(os.path.join(pymvpa_dataroot,
+                        'attributes_literal.txt'))
+dataset = fmri_dataset(samples=os.path.join(pymvpa_dataroot, 'bold.nii.gz'),
+                       targets=attr.targets, chunks=attr.chunks,
                        mask=os.path.join(pymvpa_dataroot, 'mask.nii.gz'))
 
 # do chunkswise linear detrending on dataset
-detrend(dataset, perchunk=True, model='linear')
+poly_detrend(dataset, polyord=1, chunks_attr='chunks')
 
 # zscore dataset relative to baseline ('rest') mean
-zscore(dataset, perchunk=True, baselinelabels=[0],
-       targetdtype='float32')
+zscore(dataset, chunks_attr='chunks', param_est=('targets', ['rest']))
 
-# select class 1 and 2 for this demo analysis
+# select class face and house for this demo analysis
 # would work with full datasets (just a little slower)
-dataset = dataset.selectSamples(
-                N.array([l in [1, 2] for l in dataset.labels],
-                        dtype='bool'))
+dataset = dataset[np.array([l in ['face', 'house'] for l in dataset.sa.targets],
+                          dtype='bool')]
 
 # setup cross validation procedure, using SMLR classifier
-cv = CrossValidatedTransferError(
-            TransferError(SMLR()),
-            OddEvenSplitter())
-# and run it
-error = cv(dataset)
+cv = CrossValidation(SMLR(), OddEvenPartitioner())
 
+# and run it
+error = np.mean(cv(dataset))
+
+# UC: unique chunks, UT: unique targets
 print "Error for %i-fold cross-validation on %i-class problem: %f" \
-      % (len(dataset.uniquechunks), len(dataset.uniquelabels), error)
+      % (len(dataset.UC), len(dataset.UT), error)
