@@ -24,7 +24,7 @@ if cfg.has_option('general', 'seed'):
 else:
     _random_seed = int(np.random.uniform()*(2**31-1))
 
-def seed(random_seed):
+def seed(random_seed=_random_seed):
     """Uniform and combined seeding of all relevant random number
     generators.
     """
