@@ -238,6 +238,7 @@ if __debug__:
 
     debug.register('MAP',   "*Mapper")
     debug.register('MAP_',  "*Mapper (verbose)")
+    debug.register('FX',    "FxMapper")
     debug.register('ZSCM',  "ZScoreMapper")
 
     debug.register('COL',  "Generic Collectable")
@@ -317,7 +318,6 @@ if __debug__:
                    "Internal shogun progress bar during computation")
 
     debug.register('IOH',    "IO Helpers")
-    debug.register('IO_HAM', "Hamster")
     debug.register('HDF5',   "HDF5 IO")
     debug.register('CM',   "Confusion matrix computation")
     debug.register('ROC',  "ROC analysis")
