@@ -170,6 +170,25 @@ def _parse_parameters(paramdoc):
               (paramdoc, result))
     return result
 
+def get_docstring_split(f):
+    """Given a function, break it up into portions
+
+    Parameters
+    ----------
+    f : function
+
+    Returns
+    -------
+
+    (initial doc string, params (as list of tuples), suffix string)
+    """
+
+    if not hasattr(f, '__doc__') or f.__doc__ in (None, ""):
+        return None, None, None
+    initdoc, params, suffix = _split_out_parameters(
+        f.__doc__)
+    params_list = _parse_parameters(params)
+    return initdoc, params_list, suffix
 
 def enhanced_doc_string(item, *args, **kwargs):
     """Generate enhanced doc strings for various items.
@@ -236,6 +255,8 @@ def enhanced_doc_string(item, *args, **kwargs):
         func = lcl['__init__']
         initdoc = func.__doc__
 
+        skip_params += lcl.get('__init__doc__exclude__', [])
+
         # either to extend arguments
         # do only if kwargs is one of the arguments
         # in python 2.5 args are no longer in co_names but in varnames
@@ -375,7 +396,9 @@ def table2string(table, out=None):
         out = StringIO()
 
     # equalize number of elements in each row
-    Nelements_max = max(len(x) for x in table)
+    Nelements_max = len(table) \
+                    and max(len(x) for x in table)
+
     for i, table_ in enumerate(table):
         table[i] += [''] * (Nelements_max - len(table_))
 
@@ -427,7 +450,7 @@ def _repr_attrs(obj, attrs, default=None, error_value='ERROR'):
     out = []
     for a in attrs:
         v = getattr(obj, a, error_value)
-        if not v is default:
+        if not (v is default or isinstance(v, basestring) and v == default):
             out.append('%s=%r' % (a, v))
     return out
 
@@ -457,7 +480,7 @@ def _repr(obj, *args, **kwargs):
     auto_repr = ', '.join(list(args)
                    + ["%s=%s" % (k, v) for k, v in kwargs.iteritems()])
 
-    print max_length
+
     if not truncate is None and len(auto_repr) > max_length:
         auto_repr = auto_repr[:max_length] + '...'
 
@@ -492,7 +515,9 @@ def _str(obj, *args, **kwargs):
     truncate = cfg.get_as_dtype('verbose', 'truncate str', int, default=200)
 
     s = None
-    if hasattr(obj, 'descr'):
+    # don't do descriptions for dicts like our collections as they might contain
+    # an actual item 'descr'
+    if hasattr(obj, 'descr') and not isinstance(obj, dict):
         s = obj.descr
     if s is None:
         s = obj.__class__.__name__
@@ -521,6 +546,13 @@ def _str(obj, *args, **kwargs):
 def borrowdoc(cls, methodname=None):
     """Return a decorator to borrow docstring from another `cls`.`methodname`
 
+    It should not be used for __init__ methods of classes derived from
+    ClassWithCollections since __doc__'s of those are handled by the
+    AttributeCollector anyways.
+
+    Common use is to borrow a docstring from the class's method for an
+    adapter function (e.g. sphere_searchlight borrows from Searchlight)
+
     Examples
     --------
     To borrow `__repr__` docstring from parent class `Mapper`, do::
