@@ -8,8 +8,12 @@
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Estimator for classifier error distributions."""
 
+from __future__ import with_statement   # Let's start using with
+
 __docformat__ = 'restructuredtext'
 
+import warnings
+
 import numpy as np
 
 from mvpa2.base import externals, warning
@@ -244,6 +248,11 @@ class NullDist(ClassWithCollections):
         """
         raise NotImplementedError
 
+    def dists(self):
+        """Implementations returns a sequence of the ``dist_class`` instances
+        that were used to fit the distribution.
+        """
+        raise NotImplementedError
 
     def p(self, x, return_tails=False, **kwargs):
         """Returns the p-value for values of `x`.
@@ -375,7 +384,7 @@ class MCNullDist(NullDist):
             #
             if __debug__:
                 debug('STATMC', "Doing %i permutations: %i" \
-                      % (self.__permutator.nruns, p+1), cr=True)
+                      % (self.__permutator.count, p+1), cr=True)
 
             # compute and store the measure of this permutation
             # assume it has `TransferError` interface
@@ -396,7 +405,11 @@ class MCNullDist(NullDist):
         if __debug__:
             debug('STATMC', ' Skipped: %d permutations' % skipped)
 
-
+        if not len(dist_samples) and skipped > 0:
+            raise RuntimeError(
+                'Failed to obtain any value from %s. %d measurements were '
+                'skipped. Check above warnings, and your code/data'
+                % (measure, skipped))
         # store samples as (npermutations x nsamples x nfeatures)
         dist_samples = np.asanyarray(dist_samples)
         # for the ca storage use a dataset with
@@ -466,6 +479,8 @@ class MCNullDist(NullDist):
     def rcdf(self, x):
         return self._cdf(x, 'rcdf')
 
+    def dists(self):
+        return self._dist
 
     def clean(self):
         """Clean stored distributions
@@ -921,7 +936,10 @@ if externals.exists('scipy'):
                     debug('STAT__',
                           'Fitting %s distribution %r on data of size %s',
                           (dist_name, dist_opt, data_selected.shape))
-                dist_params = dist_opt.fit(data_selected)
+                # suppress the warnings which might pop up while
+                # matching "inappropriate" distributions
+                with warnings.catch_warnings(record=True) as w:
+                    dist_params = dist_opt.fit(data_selected)
                 if __debug__:
                     debug('STAT__',
                           'Got distribution parameters %s for %s'
@@ -936,7 +954,7 @@ if externals.exists('scipy'):
                     if __debug__:
                         res_sum = 'D=%.2f' % D
                 elif test == 'kstest':
-                    D, p = kstest(data, d, args=dist_params)
+                    D, p = kstest(data, dist_gen, args=dist_params)
                     if __debug__:
                         res_sum = 'D=%.3f p=%.3f' % (D, p)
             except (TypeError, ValueError, AttributeError,
@@ -959,7 +977,7 @@ if externals.exists('scipy'):
                 continue
 
         # sort in ascending order, so smaller is better
-        results.sort()
+        results.sort(key=lambda x:x[0])
 
         if __debug__ and 'STAT' in debug.active:
             # find the best and report it
@@ -1085,8 +1103,8 @@ if externals.exists('scipy'):
                             tuple(map(np.sum, [tp, fp, fn]))
 
                 pdf = dist.pdf(x)
-                line = pl.plot(x, pdf, '-', linewidth=2, label=label)
-                color = line[0].get_color()
+                line = pl.plot(x, pdf, '-', linewidth=2, label=label)[0]
+                color = line.get_color()
 
                 if plot_cdf:
                     cdf = dist.cdf(x)
