@@ -11,7 +11,7 @@
 
 __docformat__ = 'restructuredtext'
 
-import operator
+from mvpa2.base.types import is_sequence_type
 
 # Define sets of classifiers
 from mvpa2.clfs.meta import FeatureSelectionClassifier, SplitClassifier, \
@@ -120,7 +120,7 @@ class Warehouse(object):
         return result
 
     def __iadd__(self, item):
-        if operator.isSequenceType(item):
+        if is_sequence_type(item):
             for item_ in item:
                 self.__iadd__(item_)
         else:
@@ -177,7 +177,7 @@ clfswh += \
                             descr='Pairs+maxvote multiclass on SMLR(lm=0.1)') ]
 
 if externals.exists('libsvm'):
-    from mvpa2.clfs import libsvmc as libsvm
+    from mvpa2.clfs.libsvmc import svm as libsvm
     clfswh._known_tags.update(libsvm.SVM._KNOWN_IMPLEMENTATIONS.keys())
     clfswh += [libsvm.SVM(descr="libsvm.LinSVM(C=def)", probability=1),
              libsvm.SVM(
