@@ -67,9 +67,6 @@ class Measure(Learner):
 
     """
 
-    raw_results = ConditionalAttribute(enabled=False,
-        doc="Computed results before applying any " +
-            "transformation algorithm")
     null_prob = ConditionalAttribute(enabled=True)
     """Stores the probability of a measure under the NULL hypothesis"""
     null_t = ConditionalAttribute(enabled=False)
@@ -124,8 +121,6 @@ class Measure(Learner):
     def _postcall(self, dataset, result):
         """Some postprocessing on the result
         """
-        self.ca.raw_results = result
-
         # post-processing
         result = super(Measure, self)._postcall(dataset, result)
         if not self.__null_dist is None:
@@ -268,10 +263,11 @@ class RepeatedMeasure(Measure):
         self._callback = callback
         self._concat_as = concat_as
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=[], exclude=[]):
         return super(RepeatedMeasure, self).__repr__(
             prefixes=prefixes
-            + _repr_attrs(self, ['node', 'generator', 'callback'])
+            + _repr_attrs(self, [x for x in ['node', 'generator', 'callback']
+                                 if not x in exclude])
             + _repr_attrs(self, ['concat_as'], default='samples')
             )
 
@@ -462,7 +458,11 @@ class CrossValidation(RepeatedMeasure):
             prefixes=prefixes
             + _repr_attrs(self, ['learner', 'splitter'])
             + _repr_attrs(self, ['errorfx'], default=mean_mismatch_error)
-            + _repr_attrs(self, ['space'], default='sa.cvfolds')
+            + _repr_attrs(self, ['space'], default='sa.cvfolds'),
+            # Since it is the constructor which generates and passes
+            # node=TransferMeasure, it must not be present in __repr__ of CV
+            # TODO: clear up hierarchy
+            exclude=('node',)
             )
 
 
@@ -552,6 +552,12 @@ class TransferMeasure(Measure):
         dsgen = splitter.generate(ds)
         dstrain = dsgen.next()
 
+        if not len(dstrain):
+            raise ValueError(
+                "Got empty training dataset from splitting in TransferMeasure. "
+                "Unique values of input split attribute are: %s)" \
+                % (ds.sa[splitter.get_space()].unique))
+
         if space:
             # get unique chunks for training set
             train_chunks = ','.join([str(i)
@@ -565,6 +571,11 @@ class TransferMeasure(Measure):
 
         # run with second
         dstest = dsgen.next()
+        if not len(dstest):
+            raise ValueError(
+                "Got empty testing dataset from splitting in TransferMeasure. "
+                "Unique values of input split attribute are: %s)" \
+                % (ds.sa[splitter.get_space()].unique))
         if space:
             # get unique chunks for testing set
             test_chunks = ','.join([str(i)
@@ -611,33 +622,8 @@ class FeaturewiseMeasure(Measure):
     Should behave like a Measure.
     """
 
-    # MH: why isn't this piece in the Sensitivity class?
-    base_sensitivities = ConditionalAttribute(enabled=False,
-        doc="Stores basic sensitivities if the sensitivity " +
-            "relies on combining multiple ones")
-
-    def __init__(self, **kwargs):
-        Measure.__init__(self, **kwargs)
-
-
     def _postcall(self, dataset, result):
         """Adjusts per-feature-measure for computed `result`
-
-
-        TODO: overlaps in what it does heavily with
-         CombinedSensitivityAnalyzer, thus this one might make use of
-         CombinedSensitivityAnalyzer yoh thinks, and here
-         base_sensitivities doesn't sound appropriate.
-         MH: There is indeed some overlap, but also significant differences.
-             This one operates on a single sensana and combines over second
-             axis, CombinedFeaturewiseMeasure uses first axis.
-             Additionally, 'Sensitivity' base class is
-             FeaturewiseMeasures which would have to be changed to
-             CombinedFeaturewiseMeasure to deal with stuff like
-             SMLRWeights that return multiple sensitivity values by default.
-             Not sure if unification of both (and/or removal of functionality
-             here does not lead to an overall more complicated situation,
-             without any real gain -- after all this one works ;-)
         """
         # This method get the 'result' either as a 1D array, or as a Dataset
         # everything else is illegal
@@ -648,46 +634,7 @@ class FeaturewiseMeasure(Measure):
                                "their results as 1D array, or as a Dataset "
                                "(error made by: '%s')." % repr(self))
 
-        if len(result.shape) > 1:
-            n_base = len(result)
-            """Number of base sensitivities"""
-            if self.ca.is_enabled('base_sensitivities'):
-                b_sensitivities = []
-                if not self.ca.has_key('biases'):
-                    biases = None
-                else:
-                    biases = self.ca.biases
-                    if len(self.ca.biases) != n_base:
-                        warning("Number of biases %d differs from number "
-                                "of base sensitivities %d which could happen "
-                                "when measure is collided across labels."
-                                % (len(self.ca.biases), n_base))
-                for i in xrange(n_base):
-                    if not biases is None:
-                        if n_base > 1 and len(biases) == 1:
-                            # The same bias for all bases
-                            bias = biases[0]
-                        else:
-                            bias = biases[i]
-                    else:
-                        bias = None
-                    b_sensitivities = StaticMeasure(
-                        measure = result[i],
-                        bias = bias)
-                self.ca.base_sensitivities = b_sensitivities
-
-        # XXX Remove when "sensitivity-return-dataset" transition is done
-        if __debug__ \
-           and not isinstance(result, AttrDataset) and not len(result.shape) == 1:
-            warning("FeaturewiseMeasures-related post-processing "
-                    "of '%s' doesn't return a Dataset, or 1D-array."
-                    % self.__class__.__name__)
-
-        # call base class postcall
-        result = Measure._postcall(self, dataset, result)
-
-        return result
-
+        return Measure._postcall(self, dataset, result)
 
 
 class StaticMeasure(Measure):
