@@ -14,10 +14,15 @@ if __debug__:
     from mvpa2.base import debug
 
 import numpy as np
+import tempfile, os
 
 from mvpa2.base import externals, warning
 from mvpa2.base.dochelpers import borrowkwargs, _repr_attrs
 from mvpa2.base.types import is_datasetlike
+if externals.exists('h5py'):
+    # Is optionally required for passing searchlight
+    # results via storing/reloading hdf5 files
+    from mvpa2.base.hdf5 import h5save, h5load
 
 from mvpa2.datasets import hstack, Dataset
 from mvpa2.support import copy
@@ -44,7 +49,8 @@ class BaseSearchlight(Measure):
     """Indicate that this measure is always trained."""
 
 
-    def __init__(self, queryengine, roi_ids=None, nproc=None, **kwargs):
+    def __init__(self, queryengine, roi_ids=None, nproc=None,
+                 **kwargs):
         """
         Parameters
         ----------
@@ -65,7 +71,7 @@ class BaseSearchlight(Measure):
       """
         Measure.__init__(self, **kwargs)
 
-        if nproc > 1 and not externals.exists('pprocess'):
+        if nproc is not None and nproc > 1 and not externals.exists('pprocess'):
             raise RuntimeError("The 'pprocess' module is required for "
                                "multiprocess searchlights. Please either "
                                "install python-pprocess, or reduce `nproc` "
@@ -125,10 +131,7 @@ class BaseSearchlight(Measure):
             roi_ids = np.arange(dataset.nfeatures)
 
         # pass to subclass
-        results, roi_sizes = self._sl_call(dataset, roi_ids, nproc)
-
-        if not roi_sizes is None:
-            self.ca.roi_sizes = roi_sizes
+        results = self._sl_call(dataset, roi_ids, nproc)
 
         if 'mapper' in dataset.a:
             # since we know the space we can stick the original mapper into the
@@ -168,7 +171,48 @@ class Searchlight(BaseSearchlight):
     interest, which is ran at each spatial location.
     """
 
-    def __init__(self, datameasure, queryengine, add_center_fa=False, **kwargs):
+    @staticmethod
+    def _concat_results(sl=None, dataset=None, roi_ids=None, results=None):
+        """The simplest implementation for collecting the results --
+        just put them into a list
+
+        This this implementation simply collects them into a list and
+        uses only sl. for assigning conditional attributes.  But
+        custom implementation might make use of more/less of them.
+        Implemented as @staticmethod just to emphasize that in
+        principle it is independent of the actual searchlight instance
+        """
+        # collect results
+        results = sum(results, [])
+
+        if __debug__ and 'SLC' in debug.active:
+            debug('SLC', '')            # just newline
+            resshape = len(results) and np.asanyarray(results[0]).shape or 'N/A'
+            debug('SLC', ' hstacking %d results of shape %s'
+                  % (len(results), resshape))
+
+        # but be careful: this call also serves as conversion from parallel maps
+        # to regular lists!
+        # this uses the Dataset-hstack
+        result_ds = hstack(results)
+
+        if __debug__:
+            debug('SLC', " hstacked shape %s" % (result_ds.shape,))
+
+        if sl.ca.is_enabled('roi_feature_ids'):
+            sl.ca.roi_feature_ids = [r.a.roi_feature_ids for r in results]
+        if sl.ca.is_enabled('roi_sizes'):
+            sl.ca.roi_sizes = [r.a.roi_sizes for r in results]
+
+        return result_ds
+
+
+    def __init__(self, datameasure, queryengine, add_center_fa=False,
+                 results_backend='native',
+                 results_fx=None,
+                 tmp_prefix='tmpsl',
+                 nblocks=None,
+                 **kwargs):
         """
         Parameters
         ----------
@@ -181,12 +225,38 @@ class Searchlight(BaseSearchlight):
           seed (e.g. sphere center) for the respective ROI. If True, the
           attribute is named 'roi_seed', the provided string is used as the name
           otherwise.
+        results_backend : ('native', 'hdf5'), optional
+          Specifies the way results are provided back from a processing block
+          in case of nproc > 1. 'native' is pickling/unpickling of results by
+          pprocess, while 'hdf5' would use h5save/h5load functionality.
+          'hdf5' might be more time and memory efficient in some cases.
+        results_fx : callable, optional
+          Function to process/combine results of each searchlight
+          block run.  By default it would simply append them all into
+          the list.  It receives as keyword arguments sl, dataset,
+          roi_ids, and results (iterable of lists).  It is the one to take
+          care of assigning roi_* ca's
+        tmp_prefix : str, optional
+          If specified -- serves as a prefix for temporary files storage
+          if results_backend == 'hdf5'.  Thus can specify the directory to use
+          (trailing file path separator is not added automagically).
+        nblocks : None or int
+          Into how many blocks to split the computation (could be larger than
+          nproc).  If None -- nproc is used.
         **kwargs
           In addition this class supports all keyword arguments of its
           base-class :class:`~mvpa2.measures.searchlight.BaseSearchlight`.
         """
         BaseSearchlight.__init__(self, queryengine, **kwargs)
         self.datameasure = datameasure
+        self.results_backend = results_backend.lower()
+        if self.results_backend == 'hdf5':
+            # Assure having hdf5
+            externals.exists('h5py', raise_=True)
+        self.results_fx = Searchlight._concat_results \
+                          if results_fx is None else results_fx
+        self.tmp_prefix = tmp_prefix
+        self.nblocks = nblocks
         if isinstance(add_center_fa, str):
             self.__add_center_fa = add_center_fa
         elif add_center_fa:
@@ -199,17 +269,22 @@ class Searchlight(BaseSearchlight):
             prefixes=prefixes
             + _repr_attrs(self, ['datameasure'])
             + _repr_attrs(self, ['add_center_fa'], default=False)
+            + _repr_attrs(self, ['results_backend'], default='native')
+            + _repr_attrs(self, ['results_fx', 'nblocks'])
             )
 
 
     def _sl_call(self, dataset, roi_ids, nproc):
         """Classical generic searchlight implementation
         """
+        assert(self.results_backend in ('native', 'hdf5'))
         # compute
-        if nproc > 1:
+        if nproc is not None and nproc > 1:
             # split all target ROIs centers into `nproc` equally sized blocks
             nproc_needed = min(len(roi_ids), nproc)
-            roi_blocks = np.array_split(roi_ids, nproc_needed)
+            nblocks = nproc_needed \
+                      if self.nblocks is None else self.nblocks
+            roi_blocks = np.array_split(roi_ids, nblocks)
 
             # the next block sets up the infrastructure for parallel computing
             # this can easily be changed into a ParallelPython loop, if we
@@ -217,63 +292,65 @@ class Searchlight(BaseSearchlight):
             import pprocess
             p_results = pprocess.Map(limit=nproc_needed)
             if __debug__:
-                debug('SLC', "Starting off child processes for nproc=%i"
-                      % nproc_needed)
+                debug('SLC', "Starting off %s child processes for nblocks=%i"
+                      % (nproc_needed, nblocks))
             compute = p_results.manage(
                         pprocess.MakeParallel(self._proc_block))
-            for block in roi_blocks:
+            for iblock, block in enumerate(roi_blocks):
                 # should we maybe deepcopy the measure to have a unique and
                 # independent one per process?
-                compute(block, dataset, copy.copy(self.__datameasure))
-
-            # collect results
-            results = []
-            if self.ca.is_enabled('roi_sizes'):
-                roi_sizes = []
-            else:
-                roi_sizes = None
-
-            for r, rsizes in p_results:
-                results += r
-                if not roi_sizes is None:
-                    roi_sizes += rsizes
+                compute(block, dataset, copy.copy(self.__datameasure),
+                        iblock=iblock)
         else:
-            # otherwise collect the results in a list
-            results, roi_sizes = \
-                    self._proc_block(roi_ids, dataset, self.__datameasure)
+            # otherwise collect the results in an 1-item list
+            p_results = [
+                    self._proc_block(roi_ids, dataset, self.__datameasure)]
 
-        if __debug__ and 'SLC' in debug.active:
-            debug('SLC', '')            # just newline
-            resshape = len(results) and np.asanyarray(results[0]).shape or 'N/A'
-            debug('SLC', ' hstacking %d results of shape %s'
-                  % (len(results), resshape))
+        # Finally collect and possibly process results
+        # p_results here is either a generator from pprocess.Map or a list.
+        # In case of a generator it allows to process results as they become
+        # available
+        result_ds = self.results_fx(sl=self,
+                                    dataset=dataset,
+                                    roi_ids=roi_ids,
+                                    results=self.__handle_all_results(p_results))
 
-        # but be careful: this call also serves as conversion from parallel maps
-        # to regular lists!
-        # this uses the Dataset-hstack
-        result_ds = hstack(results)
-        if self.ca.is_enabled('roi_feature_ids'):
-            self.ca.roi_feature_ids = [r.a.roi_feature_ids for r in results]
+        # Assure having a dataset (for paranoid ones)
+        if not is_datasetlike(result_ds):
+            try:
+                result_a = np.atleast_1d(result_ds)
+            except ValueError, e:
+                if 'setting an array element with a sequence' in str(e):
+                    # try forcing object array.  Happens with
+                    # test_custom_results_fx_logic on numpy 1.4.1 on Debian
+                    # squeeze
+                    result_a = np.array(result_ds, dtype=object)
+                else:
+                    raise
+            result_ds = Dataset(result_a)
 
-        if __debug__:
-            debug('SLC', " hstacked shape %s" % (result_ds.shape,))
-
-        return result_ds, roi_sizes
+        return result_ds
 
 
-    def _proc_block(self, block, ds, measure):
+    def _proc_block(self, block, ds, measure, iblock='main'):
         """Little helper to capture the parts of the computation that can be
         parallelized
+
+        Parameters
+        ----------
+        iblock
+          Critical for generating non-colliding temp filenames in case
+          of hdf5 backend.  Otherwise RNGs of different processes might
+          collide in their temporary file names leading to problems.
         """
         if __debug__:
             debug_slc_ = 'SLC_' in debug.active
             debug('SLC',
                   "Starting computing block for %i elements" % len(block))
-        if self.ca.is_enabled('roi_sizes'):
-            roi_sizes = []
-        else:
-            roi_sizes = None
         results = []
+        store_roi_feature_ids = self.ca.is_enabled('roi_feature_ids')
+        store_roi_sizes = self.ca.is_enabled('roi_sizes')
+        assure_dataset = store_roi_feature_ids or store_roi_sizes
         # put rois around all features in the dataset and compute the
         # measure within them
         for i, f in enumerate(block):
@@ -295,18 +372,17 @@ class Searchlight(BaseSearchlight):
 
             # compute the datameasure and store in results
             res = measure(roi)
-            if self.ca.is_enabled('roi_feature_ids'):
-                if not is_datasetlike(res):
-                    res = Dataset(np.atleast_1d(res))
+
+            if assure_dataset and not is_datasetlike(res):
+                res = Dataset(np.atleast_1d(res))
+            if store_roi_feature_ids:
                 # add roi feature ids to intermediate result dataset for later
                 # aggregation
                 res.a['roi_feature_ids'] = roi_fids
+            if store_roi_sizes:
+                res.a['roi_sizes'] = roi.nfeatures
             results.append(res)
 
-            # store the size of the roi dataset
-            if not roi_sizes is None:
-                roi_sizes.append(roi.nfeatures)
-
             if __debug__:
                 debug('SLC', "Doing %i ROIs: %i (%i features) [%i%%]" \
                     % (len(block),
@@ -314,7 +390,21 @@ class Searchlight(BaseSearchlight):
                        roi.nfeatures,
                        float(i+1)/len(block)*100,), cr=True)
 
-        return results, roi_sizes
+        if self.results_backend == 'native':
+            pass                        # nothing special
+        elif self.results_backend == 'hdf5':
+            # store results in a temporary file and return a filename
+            results_file = tempfile.mktemp(prefix=self.tmp_prefix,
+                                           suffix='-%s.hdf5' % iblock)
+            if __debug__:
+                debug('SLC', "Storing results into %s" % results_file)
+            h5save(results_file, results)
+            if __debug__:
+                debug('SLC_', "Results stored")
+            results = results_file
+        else:
+            raise RuntimeError("Must not reach this point")
+        return results
 
 
     def __set_datameasure(self, datameasure):
@@ -322,6 +412,29 @@ class Searchlight(BaseSearchlight):
         self.untrain()
         self.__datameasure = datameasure
 
+    def __handle_results(self, results):
+        if self.results_backend == 'hdf5':
+            # 'results' must be just a filename
+            assert(isinstance(results, str))
+            if __debug__:
+                debug('SLC', "Loading results from %s" % results)
+            results_data = h5load(results)
+            os.unlink(results)
+            if __debug__:
+                debug('SLC_', "Loaded results of len=%d from"
+                      % len(results_data))
+            return results_data
+        else:
+            return results
+
+    def __handle_all_results(self, results):
+        """Helper generator to decorate passing the results out to
+        results_fx
+        """
+        for r in results:
+            yield self.__handle_results(r)
+
+
     datameasure = property(fget=lambda self: self.__datameasure,
                            fset=__set_datameasure)
     add_center_fa = property(fget=lambda self: self.__add_center_fa)
