@@ -10,11 +10,11 @@
 
 import numpy as np
 from numpy import array
-import operator
 import sys
 import itertools
 
 from mvpa2.base import warning
+from mvpa2.base.types import is_sequence_type
 from mvpa2.base.dochelpers import borrowkwargs, borrowdoc, _repr_attrs, _repr
 from mvpa2.clfs.distance import cartesian_distance
 
@@ -620,7 +620,6 @@ class CachedQueryEngine(QueryEngineInterface):
     def query(self, **kwargs):
         def to_hashable(x):
             """Convert x to something which dict wouldn't mind"""
-            import operator
             try:
                 # silly attempt
                 d = {x: None}
@@ -633,7 +632,7 @@ class CachedQueryEngine(QueryEngineInterface):
                 # and sort for deterministic order
                 return tuple((k, to_hashable(v))
                              for (k, v) in sorted(x.iteritems()))
-            elif operator.isSequenceType(x):
+            elif is_sequence_type(x):
                 return tuple(i for i in x)
             elif np.isscalar(x):
                 return x
