@@ -175,6 +175,7 @@ def collect_nose_tests(verbosity=1):
         'test_niftidataset',
         'test_eepdataset',
         'test_erdataset',
+        'test_datasrcs',
 
         # Classifiers
         'test_multiclf',
@@ -334,4 +335,4 @@ run.__test__ = False
 __test__ = False
 
 if __name__ == "__main__":
-    run(exit_=True)
+    run(exit_=True, verbosity=3)
