@@ -9,6 +9,8 @@
 """Unit tests for PyMVPA cmdline helpers"""
 
 import unittest
+from mvpa2.testing import *
+
 from mvpa2.misc.cmdline import *
 
 if __debug__:
@@ -24,6 +26,16 @@ class CmdlineHelpersTest(unittest.TestCase):
             self.assertTrue(globals_.has_key(member),
                 msg="We must have imported %s from mvpa2.misc.cmdline!" % member)
 
+    @sweepargs(example=[
+        ('targets:rest', None, [('targets', ['rest'])]),
+        ('targets:rest;trial:bad,crap,shit', None,
+         [('targets', ['rest']), ('trial', ['bad', 'crap', 'shit'])]),
+        ])
+    def test_split_comma_semicolon_lists(self, example):
+        s, dtype, t = example
+        v = split_comma_semicolon_lists(s, dtype=dtype)
+        assert_equal(v, t)
+
 def suite():
     return unittest.makeSuite(CmdlineHelpersTest)
 
