@@ -12,17 +12,24 @@
 import unittest
 import numpy as np
 from numpy.linalg import norm
+from mvpa2.base import externals
 from mvpa2.datasets.base import dataset_wizard
 from mvpa2.testing import *
 from mvpa2.testing.datasets import *
 from mvpa2.mappers.procrustean import ProcrusteanMapper
 
+svds = ['numpy']
+if externals.exists('liblapack.so'):
+    svds += ['dgesvd']
+if externals.exists('scipy'):
+    svds += ['scipy']
 
 class ProcrusteanMapperTests(unittest.TestCase):
 
     @sweepargs(oblique=(False,True))
+    @sweepargs(svd=svds)
     @reseed_rng()
-    def test_simple(self, oblique):
+    def test_simple(self, svd, oblique):
         d_orig = datasets['uni2large'].samples
         d_orig2 = datasets['uni4large'].samples
         for sdim, nf_s, nf_t, full_test \
@@ -42,7 +49,7 @@ class ProcrusteanMapperTests(unittest.TestCase):
                                      - np.eye(R.shape[0])) < 1e-10)
 
             for s, scaling in ((0.3, True), (1.0, False)):
-                pm = ProcrusteanMapper(scaling=scaling, oblique=oblique)
+                pm = ProcrusteanMapper(scaling=scaling, oblique=oblique, svd=svd)
                 # pm2 = ProcrusteanMapper(scaling=scaling, oblique=oblique)
 
                 t1, t2 = d_orig[23, 1], d_orig[22, 1]
