@@ -224,6 +224,32 @@ class StatsTestsScipy(unittest.TestCase):
                         #pl.show()
                         pl.close(fig)
 
+    def test_match_distribution_semifrozen(self):
+        """Handle frozen params in match_distribution
+        """
+        matches = match_distribution(np.arange(10),
+                                     distributions=[
+                                         'uniform',
+                                         ('uniform', {'loc': 0})
+                                         ],
+                                     p=-1 # so we get all matches
+                                     )
+        self.assertEqual(len(matches), 2) # we must get some match
+
+        self.assertTrue(abs(matches[0][-1][0]) < 4e-1) # full fit should get close to true loc
+        self.assertEqual(matches[1][-1][0], 0) # frozen should maintain the loc
+
+        if externals.versions['scipy'] >= '0.10':
+            # known to work on 0.10 and fail on 0.7.3
+            self.assertTrue(abs(matches[0][-1][1]-9) < 1e-1) # full fit should get close to true scale
+        else:
+            raise SkipTest("KnownFailure to fit uniform on older scipy")
+
+        # actually it fails ATM to fit uniform with frozen loc=0
+        # nicely -- sets scale = 1 :-/   TODO
+        raise SkipTest("TODO: Known failure to fit uniform with frozen loc")
+        self.assertTrue(abs(matches[1][-1][1]-9) < 1e-1) # frozen fit of scale
+
     def test_r_dist_stability(self):
         """Test either rdist distribution performs nicely
         """
@@ -263,6 +289,20 @@ class StatsTestsScipy(unittest.TestCase):
         v = scipy.stats.rdist(10000, 0, 1).cdf([-0.1])
         self.assertTrue(v>=0, v<=1)
 
+    @reseed_rng()
+    def test_scipy_fit_2fparams(self):
+        # fixing parameters was not before this version
+        skip_if_no_external('scipy', min_version='0.8.0')
+        t = scipy.stats.t
+        d = t(10, 1, 10).rvs(10)
+        params = t.fit(d, floc=1, fscale=10.)
+        # assured result to be a tuple due to failure on
+        # travis-ci (ubuntu precise)
+        # http://travis-ci.org/#!/PyMVPA/PyMVPA/builds/2459017
+        self.assertEqual(tuple(params[1:]), (1, 10.))
+        # df's are apparently quite difficult to assess unless plenty
+        # of samples
+        #self.assertTrue(abs(params[0] - 10) < 7) # estimate df at least in the right ball park
 
     def test_anova_compliance(self):
         ds = datasets['uni2large']
